insightvault.app package
========================

Submodules
----------

insightvault.app.base module
----------------------------

.. automodule:: insightvault.app.base
   :members:
   :undoc-members:
   :show-inheritance:

insightvault.app.cli module
---------------------------

.. automodule:: insightvault.app.cli
   :members:
   :undoc-members:
   :show-inheritance:

insightvault.app.rag module
---------------------------

.. automodule:: insightvault.app.rag
   :members:
   :undoc-members:
   :show-inheritance:

insightvault.app.search module
------------------------------

.. automodule:: insightvault.app.search
   :members:
   :undoc-members:
   :show-inheritance:

insightvault.app.summarizer module
----------------------------------

.. automodule:: insightvault.app.summarizer
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: insightvault.app
   :members:
   :undoc-members:
   :show-inheritance:
